@@ -1,10 +1,50 @@
 CREATE DOMAIN postgres_table_view_name AS varchar(64) CHECK (VALUE ~* '^[A-Za-z*0-9_\-]+$');
 
+create table jaaql__email_account (
+    id uuid PRIMARY KEY NOT NULL not null default gen_random_uuid(),
+    name varchar(255) not null,
+    send_name varchar(255) not null,
+    protocol varchar(4) not null,
+    check (protocol in ('smtp', 'imap')),
+    host varchar(255) not null,
+    port integer not null,
+    username varchar(255) not null,
+    encrypted_password text not null,
+    deleted timestamptz default null
+);
+CREATE UNIQUE INDEX jaaql__email_account_unq
+    ON jaaql__email_account (name) WHERE (deleted is null);
+
+create table jaaql__email_template (
+    id uuid PRIMARY KEY NOT NULL not null default gen_random_uuid(),
+    name varchar(60) NOT NULL,
+    subject varchar(255),
+    account uuid NOT NULL,
+    FOREIGN KEY (account) REFERENCES jaaql__email_account,
+    description text,
+    app_relative_path postgres_table_view_name,  -- Not a mistake for this domain type
+    check ((subject is null) = (app_relative_path is null)),
+    data_validation_table postgres_table_view_name,
+    data_validation_view postgres_table_view_name,
+    CHECK ((data_validation_table is null and data_validation_view is null) or data_validation_table is not null),
+    recipient_validation_view postgres_table_view_name,
+    allow_signup boolean default false not null,
+    allow_confirm_signup_attempt boolean default false not null,
+    check ((allow_signup <> jaaql__email_template.allow_confirm_signup_attempt) or not allow_signup),
+    deleted timestamptz default null
+);
+CREATE UNIQUE INDEX jaaql__email_template_unq
+    ON jaaql__email_template (name) WHERE (deleted is null);
+
 create table jaaql__application (
     name varchar(64) not null primary key,
     description varchar(256) not null,
     url text not null,
-    created timestamptz not null default current_timestamp
+    created timestamptz not null default current_timestamp,
+    default_email_signup_template uuid,
+    FOREIGN KEY (default_email_signup_template) REFERENCES jaaql__email_template,
+    default_email_already_signed_up_template uuid,
+    FOREIGN KEY (default_email_already_signed_up_template) REFERENCES jaaql__email_template
 );
 
 create table jaaql__user (
@@ -38,17 +78,6 @@ create table jaaql__user_ip (
     constraint jaaql__user_ip_unq unique (the_user, address_hash)
 );
 
-create table jaaql__user_ua (
-    id uuid PRIMARY KEY NOT NULL default gen_random_uuid(),
-    the_user uuid not null,
-    ua_hash varchar(254),
-    encrypted_ua varchar(512),
-    first_use timestamptz not null default current_timestamp,
-    most_recent_use timestamptz not null default current_timestamp,
-    FOREIGN KEY (the_user) REFERENCES jaaql__user,
-    constraint jaaql__user_ua_unq unique (the_user, ua_hash)
-);
-
 create table jaaql__user_password (
     the_user uuid not null,
     created timestamptz not null default current_timestamp,
@@ -78,6 +107,17 @@ create view jaaql__user_latest_password as (
         sub.change_count <= 1 AND us.deleted is null
 );
 
+create view jaaql__user_latest_credentials as (
+    SELECT
+        julp.*,
+        juip.id as ip_id,
+        juip.address_hash
+    FROM
+        jaaql__user_latest_password julp
+    INNER JOIN
+        jaaql__user_ip juip ON juip.the_user = julp.id
+);
+
 create table jaaql__node (
     name varchar(255) primary key not null,
     description varchar(255) not null,
@@ -202,11 +242,9 @@ create table jaaql__log (
     encrypted_exception text,
     encrypted_input text,
     ip uuid not null,
-    ua uuid,
     status int not null,
     endpoint varchar(64) not null,
     FOREIGN KEY (the_user) REFERENCES jaaql__user,
-    FOREIGN KEY (ua) REFERENCES jaaql__user_ua,
     FOREIGN KEY (ip) REFERENCES jaaql__user_ip
 );
 
@@ -222,7 +260,6 @@ create view jaaql__my_logs as (
     SELECT
         log.occurred,
         ip.encrypted_address,
-        ua.encrypted_ua,
         log.status,
         log.endpoint,
         log.duration_ms,
@@ -231,7 +268,6 @@ create view jaaql__my_logs as (
          jaaql__log log
     INNER JOIN jaaql__user us ON us.id = log.the_user AND us.deleted is null AND us.email = current_user
     INNER JOIN jaaql__user_ip ip ON log.ip = ip.id
-    LEFT JOIN jaaql__user_ua ua ON log.ua = ua.id
     ORDER BY occurred DESC
 );
 grant select on jaaql__my_logs to public;
@@ -389,42 +425,6 @@ BEGIN
 END
 $$ language plpgsql;
 
-create table jaaql__email_account (
-    id uuid PRIMARY KEY NOT NULL not null default gen_random_uuid(),
-    name varchar(255) not null,
-    send_name varchar(255) not null,
-    protocol varchar(4) not null,
-    check (protocol in ('smtp', 'imap')),
-    host varchar(255) not null,
-    port integer not null,
-    username varchar(255) not null,
-    encrypted_password text not null,
-    deleted timestamptz default null
-);
-CREATE UNIQUE INDEX jaaql__email_account_unq
-    ON jaaql__email_account (name) WHERE (deleted is null);
-
-create table jaaql__email_template (
-    id uuid PRIMARY KEY NOT NULL not null default gen_random_uuid(),
-    name varchar(60) NOT NULL,
-    subject varchar(255),
-    account uuid NOT NULL,
-    FOREIGN KEY (account) REFERENCES jaaql__email_account,
-    description text,
-    app_relative_path postgres_table_view_name,  -- Not a mistake for this domain type
-    check ((subject is null) = (app_relative_path is null)),
-    data_validation_table postgres_table_view_name,
-    data_validation_view postgres_table_view_name,
-    CHECK ((data_validation_table is null and data_validation_view is null) or data_validation_table is not null),
-    recipient_validation_view postgres_table_view_name,
-    allow_signup boolean default false not null,
-    allow_confirm_signup_attempt boolean default false not null,
-    check ((allow_signup <> jaaql__email_template.allow_confirm_signup_attempt) or not allow_signup),
-    deleted timestamptz default null
-);
-CREATE UNIQUE INDEX jaaql__email_template_unq
-    ON jaaql__email_template (name) WHERE (deleted is null);
-
 create view jaaql__email_templates as (
     SELECT
         jet.deleted,
@@ -458,12 +458,15 @@ create table jaaql__email_history (
 create table jaaql__sign_up (
     key_a uuid PRIMARY KEY not null default gen_random_uuid(),
     key_b uuid not null default gen_random_uuid(),
+    invite_code varchar(4) not null,
     activated boolean not null default false,
+    used_key_a boolean not null default false,
     the_user uuid not null,
     FOREIGN KEY (the_user) REFERENCES jaaql__user,
     closed timestamptz,
     created timestamptz default current_timestamp not null,
     expiry_ms integer not null default 1000 * 60 * 60 * 24 * 14, -- 2 weeks
+    code_expiry_ms integer not null default 1000 * 60 * 15, -- 15 minutes
     email_template uuid,
     FOREIGN KEY (email_template) REFERENCES jaaql__email_template,
     data_lookup_json text,
